@@ -23,7 +23,7 @@ package Spreadsheet::Read;
 use strict;
 use warnings;
 
-our $VERSION = "0.45";
+our $VERSION = "0.46";
 sub  Version { $VERSION }
 
 use Carp;
@@ -57,6 +57,18 @@ for (@parsers) {
 $can{sc} = __PACKAGE__;	# SquirelCalc is built-in
 
 my $debug = 0;
+my %def_opts = (
+    rc      => 1,
+    cells   => 1,
+    attr    => 0,
+    clip    => undef, # $opt{cells};
+    strip   => 0,
+    dtfmt   => "yyyy-mm-dd", # Format 14
+    debug   => 0,
+    parser  => undef,
+    sep     => undef,
+    quote   => undef,
+    );
 my @def_attr = (
     type    => "text",
     fgcolor => undef,
@@ -171,9 +183,10 @@ sub _clipsheets
 {
     my ($opt, $ref) = @_;
 
-    if (my $s = $opt->{strip}) {
+    if (my $s = $opt->{strip} and $ref->[0]{sheets}) {
 	foreach my $sheet (1 .. $ref->[0]{sheets}) {
 	    my $ss = $ref->[$sheet];
+	    $ss->{maxrow} && $ss->{maxcol} or next;
 	    foreach my $row (1 .. $ss->{maxrow}) {
 		foreach my $col (1 .. $ss->{maxcol}) {
 		    defined $ss->{cell}[$col][$row] or next;
@@ -236,17 +249,22 @@ sub ReadData
 	   if (ref $_[0] eq "HASH")  { %opt = %{shift @_} }
 	elsif (@_ % 2 == 0)          { %opt = @_          }
 	}
-    defined $opt{rc}	or $opt{rc}	= 1;
-    defined $opt{cells}	or $opt{cells}	= 1;
-    defined $opt{attr}	or $opt{attr}	= 0;
+
+    defined $opt{rc}	or $opt{rc}	= $def_opts{rc};
+    defined $opt{cells}	or $opt{cells}	= $def_opts{cells};
+    defined $opt{attr}	or $opt{attr}	= $def_opts{attr};
     defined $opt{clip}	or $opt{clip}	= $opt{cells};
-    defined $opt{strip}	or $opt{strip}	= 0;
-    defined $opt{dtfmt} or $opt{dtfmt}	= "yyyy-mm-dd"; # Format 14
+    defined $opt{strip}	or $opt{strip}	= $def_opts{strip};
+    defined $opt{dtfmt} or $opt{dtfmt}	= $def_opts{dtfmt};
 
     # $debug = $opt{debug} // 0;
-    $debug = defined $opt{debug} ? $opt{debug} : 0;
+    $debug = defined $opt{debug} ? $opt{debug} : $def_opts{debug};
     $debug > 4 and print STDERR Data::Dumper->Dump ([\%opt],["Options"]);
 
+    my %parser_opts = map { $_ => $opt{$_} }
+		      grep { !exists $def_opts{$_} }
+		      keys %opt;
+
     my $io_ref = ref ($txt) =~ m/GLOB|IO/ ? $txt : undef;
     my $io_fil = $io_ref ? 0 : do { no warnings "newline"; -f $txt ? 1 : 0 };
     my $io_txt = $io_ref || $io_fil ? 0 : 1;
@@ -310,6 +328,8 @@ sub ReadData
 	    }
 	$debug > 1 and print STDERR "CSV sep_char '$sep', quote_char '$quo'\n";
 	$csv = $can{csv}->new ({
+	    %parser_opts,
+
 	    sep_char       => ($data[0]{sepchar} = $sep),
 	    quote_char     => ($data[0]{quote}   = $quo),
 	    keep_meta_info => 1,
@@ -368,14 +388,13 @@ sub ReadData
 	if ($io_ref) {
 	    $oBook = $parse_type eq "XLSX"
 		? Spreadsheet::XLSX->new ($io_ref)
-		: Spreadsheet::ParseExcel::Workbook->Parse ($io_ref);
+		: Spreadsheet::ParseExcel->new (%parser_opts)->Parse ($io_ref);
 	    }
 	else {
 	    $oBook = $parse_type eq "XLSX"
 		? Spreadsheet::XLSX->new ($txt)
-		: Spreadsheet::ParseExcel::Workbook->Parse ($txt);
+		: Spreadsheet::ParseExcel->new (%parser_opts)->Parse ($txt);
 	    }
-	$oBook or return;
 	$debug > 8 and print STDERR Data::Dumper->Dump ([$oBook],["oBook"]);
 	my @data = ( {
 	    type	=> lc $parse_type,
@@ -569,7 +588,7 @@ sub ReadData
     if ($opt{parser} ? _parser ($opt{parser}) eq "sxc"
 		     : ($txt =~ m/^<\?xml/ or -f $txt)) {
 	$can{sxc} or croak "Spreadsheet::ReadSXC not installed";
-	my $sxc_options = { OrderBySheet => 1 }; # New interface 0.20 and up
+	my $sxc_options = { %parser_opts, OrderBySheet => 1 }; # New interface 0.20 and up
 	my $sxc;
 	   if ($txt =~ m/\.(sxc|ods)$/i) {
 	    $debug and print STDERR "Opening \U$1\E $txt\n";
@@ -811,6 +830,9 @@ parser.
 
 =back
 
+All other attributes/options will be passed to the underlying parser if
+that parser supports attributes.
+
 =back
 
 =head2 Using CSV
@@ -1045,7 +1067,7 @@ H.Merijn Brand, <h.m.brand@xs4all.nl>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2011 H.Merijn Brand
+Copyright (C) 2005-2012 H.Merijn Brand
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
